]> git.sur5r.net Git - groeck-it87/commitdiff
it87: IT8783E/F only support three fans
authorGuenter Roeck <linux@roeck-us.net>
Sat, 3 Mar 2012 17:07:39 +0000 (09:07 -0800)
committerGuenter Roeck <linux@roeck-us.net>
Sat, 3 Mar 2012 17:10:07 +0000 (09:10 -0800)
Signed-off-by: Guenter Roeck <linux@roeck-us.net>
it87.c

diff --git a/it87.c b/it87.c
index 4421f2ae192240977bf6bb9e893bbd52ba85f1c3..998cbd4d35c4aaa702ee2faea3ba281be7de0e21 100644 (file)
--- a/it87.c
+++ b/it87.c
@@ -2253,8 +2253,8 @@ static void __devinit it87_init_device(struct platform_device *pdev)
                        it87_write_value(data, IT87_REG_FAN_16BIT,
                                         tmp | 0x07);
                }
-               /* IT8705F only supports three fans. */
-               if (data->type != it87) {
+               /* IT8705F and IT8783E/F only support three fans. */
+               if (data->type != it87 && data->type != it8783) {
                        if (tmp & (1 << 4))
                                data->has_fan |= (1 << 3); /* fan4 enabled */
                        if (tmp & (1 << 5))